# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution	
#    Copyright (C) 2004-2008 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
import time
from dateutil.relativedelta import relativedelta
from datetime import datetime
from osv import osv, fields






class partner_laboratory(osv.osv):

 #Get the patient age in the following format : "YEARS MONTHS"

	def _patient_age(self, cr, uid, ids, name, arg, context={}):
		def compute_age_from_dates (partner_dob):
			now=datetime.today()
			if (partner_dob):
				dob=datetime.strptime(partner_dob,'%Y-%m-%d')
				delta=relativedelta (now, dob)
				years_months = str(delta.years) +" years "+ str(delta.months) +"  months" 
			else:
				years_months = "No Date of Birth!"
 
			return years_months
		result={}
	        for partner_laboratory in self.browse(cr, uid, ids, context=context):
	            result[partner_laboratory.id] = compute_age_from_dates (partner_laboratory.dob)
	        return result

	_name = 'res.partner'
	_inherit = 'res.partner'
	_columns = {
		'patient': fields.boolean('Patient',help="Check if the partner is a patient"),
		'medic': fields.boolean('Medic', help="Check if the partner is a doctor"), 
		'sex' : fields.selection((('m','Male'), ('f','Female')),'Sex'),
		'dob' : fields.date('Date of birth'),
		'age' : fields.function(_patient_age, method=True, type='char', size=32, string='Patient Age', help="It shows the age of the patient in years and months."),
	}

partner_laboratory()

class sale_order_laboratory(osv.osv):	
	_name = 'sale.order'
	_inherit = 'sale.order'

	def _sel_func(self, cr, uid, context={}):
		obj = self.pool.get('res.partner')
		ids = obj.search(cr, uid, [])
		res = obj.read(cr, uid, ids, ['name', 'sex'], context)
		res = [(r['sex'], r['name']) for r in res]
		return res

	_columns = {
		'medic': fields.many2one('res.partner', 'Medic', readonly=True, required=True, states={'draft':[('readonly', False)]}, change_default=True, help="Select the medic whom sent the patient"),
		'dob': fields.many2one('res.partner', 'Date of Birth', readonly=True),
		'sex': fields.many2one('res.partner', 'Sex', selection=_sel_func), 
	}
	_defaults = {
		
	}

	def onchange_partner_dob(self, cr, uid, ids, date):
		dob = {}
		if not date:
                	return {'value' : {'dob': False}}
		part1 = self.pool.get('res.partner').read(cr, uid, ids, ['name','dob'], context=context)
		dob['dob'] = part1 or False
		return {'value' : dob }


sale_order_laboratory()

class product_laboratory(osv.osv):
	_name = 'product.product'
	_inherit = 'product.product'
	_columns = {
	}
product_laboratory()
